==> koffice_1.6.1.orig.tar.gz: koffice-1.6.1.orig/krita/plugins/paintops/cpaint/stroke.h <==
/*
 *  Copyright (c) 2000 Clara Chan
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef STROKE_H
#define STROKE_H

#include "sample.h"
#include <vector.h>
#include <math.h>
#include <stdio.h>
#include <kis_types.h>
#include <kis_color.h>

#include "brush.h"
#define MAXBRUSHSIZE 100


class Stroke {

  private :

    KisColor m_color;

    double lastx1, lasty1, lastx2, lasty2;
    vector<double> *oldPathx, *oldPathy;
    vector<int> *valid;
    Brush *brush;
    int numBristles;
    int newStroke;

    int testThreshold ( int, double, double, double );

  protected :
    
    int sealFlag;
    
  public :

    vector<Sample*> sampleV;

    Stroke (Brush *brush);
    virtual ~Stroke() {};

    void Draw (KisPaintDeviceSP);
    void Redraw ();
    void FreeSamples ();
    void StoreColor ( const KisColor & c );
    void StoreOldPath ( double, double );
    void ResetBrush ();

};

#endif

==> koffice2_1.9.93.orig.tar.gz: koffice-1.9.93/krita/plugins/paintops/cpaint/stroke.h <==
/*
 *  Copyright (c) 2000 Clara Chan
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef STROKE_H
#define STROKE_H

#include <vector.h>
#include <math.h>
#include <stdio.h>

class Brush;
class Sample;
class KoColor;

class Stroke {

public:

    vector<Sample*> sampleV;

public:

    Stroke (Brush *brush);
    virtual ~Stroke();

    void draw (QPainter &);
    void setColor ( const KoColor & c );
    void storeOldPath ( double, double );

private:

    KoColor m_color;

    double lastx1, lasty1, lastx2, lasty2;
    vector<double> *oldPathx, *oldPathy;
    vector<int> *valid;
    Brush *brush;
    int numBristles;

    // test whether a bristle is touching the paper or not
    // by testing the pressure threshold and test if there is any ink
    bool testThreshold ( int, double, double, double );


};

#endif
